package Qt::Gui::QStyleOptionComplex;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QStyleOptionComplex
# file     : QtGui/qstyleoption.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Gui::QStyleOption/;
#our @ISA = qw/Qt::Gui::QStyleOption/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QStyleOptionComplex

=head1 PUBLIC METHODS

=over

=item   QStyleOptionComplex(const QStyleOptionComplex & other)

=item   QStyleOptionComplex(int version, int type)

=item   QStyleOptionComplex(int version, int type = QStyleOptionComplex::SO_Complex)

=item   QStyleOptionComplex(int version = QStyleOptionComplex::Version, int type = QStyleOptionComplex::SO_Complex)


=back

=head1 ENUM VALUES

=over

=item Type

=item Version


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
